from setuptools import setup, find_packages
import os,re
with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()
version=re.findall(r"[0-9]+.[0-9]+.[0-9]+",os.environ["GITHUB_REF"])[0]
setup_args = dict(
    name='control_tools',
    version=version,
    description='Useful tools to make an automated actions script ',
    long_description_content_type="text/markdown",
    long_description=README + '\n\n' + HISTORY,
    license='MIT',
    packages=find_packages(),
    author='Badreddine bencherki',
    author_email='badrbencherki@gmail.com',
    keywords=['bot', 'control', 'clock','timer',],
    url='https://github.com/badre2dine/control_tools',
    download_url='https://pypi.org/project/control_tools/'
)

install_requires = []

if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)